@@ -14,7 +14,7 @@ import numpy as np
 def sample_diversity(frame, indices='Hill_1', **kwargs):
     '''
     Calculate diversity indices of all rows. 
-    See pysurvey.analysis.diversity.sample_diversity for detailed documentation.
+    See :func:`pysurvey.analysis.diversity.sample_diversity` for detailed documentation.
     
     Note that some methods work only with unnormalized data!
         
@@ -27,12 +27,14 @@ def sample_diversity(frame, indices='Hill_1', **kwargs):
     indices : str/iterable (default 'Hill_1')
         list of indices of diversity to use. 
         Valid values:
-          Hill_n   = Hill number of order n
-          Richness = Sames as Hill_0.
-          Shannon  = Shannon entropy. Same as Reyni_1.
-          Renyi_n  = Reyni enropy of order n. Same as log(Hill_n). Reyni_1 is the Shannon entropy.
-          Simpson  = Simpson's index of diversity. Same as 1/Hill_2.
-          Simpson_Inv = The inverse of simpson's index. Same as Hill_2.
+        
+        - Hill_n   = Hill number of order n
+        - Richness = Sames as Hill_0.
+        - Shannon  = Shannon entropy. Same as Reyni_1.
+        - Renyi_n  = Reyni enropy of order n. Same as log(Hill_n). Reyni_1 is the Shannon entropy.
+        - Simpson  = Simpson's index of diversity. Same as 1/Hill_2.
+        - Simpson_Inv = The inverse of simpson's index. Same as Hill_2.
+    
     methods : str/iterable (default 'ML')
         list of same length as indices detailing the methods used to calculate each index.
         Default is ML for all methods.
@@ -56,30 +58,33 @@ def sample_diversity(frame, indices='Hill_1', **kwargs):
 def dist_mat(frame, metric='euclidean', axis=0, **kwargs):
     '''
     Calculate the (symmetric) pairwise distnce metric.
-    scipy.cluster.hierarchy.distance.pdist is used to do the actual
+    :func:`scipy.cluster.hierarchy.distance.pdist` is used to do the actual
     distance computation.
     
     Parameters
     ----------
     metric : str/callable
-        Any metric supported by scipy.cluster.hierarchy.distance.pdist
+        Any metric supported by :func:`scipy.cluster.hierarchy.distance.pdist`
         Additional supported metrics:
-            - JS : Jensen-Shannon divergence. 
-                   Information theoretic measure of distance between 
-                   distributions (or any sets of numbers who's sum is 1). 
-                   Gives each taxa a weight proportional to its relative abundance.
-            - JSsqrt : the square-root of Jensen-Shannon divergence. 
-                       Upholds the triangular inequality, and is therefore a 
-                       true metric.
-
-            - Morisita : the Morisita-Horn dissimilarity index. 
-                         Gives more weight to more abundant taxa. 
+        
+        - JS - Jensen-Shannon divergence. 
+          Information theoretic measure of distance between 
+          distributions (or any sets of numbers who's sum is 1). 
+          Gives each taxa a weight proportional to its relative abundance.               
+        - JSsqrt - the square-root of Jensen-Shannon divergence. 
+          Upholds the triangular inequality, and is therefore a 
+          true metric.
+        - Morisita - the Morisita-Horn dissimilarity index. 
+          Gives more weight to more abundant taxa. 
+    
     axis :  {0 (default)| 1}
-        0 : calculate distance between rows.
-        1 : calculate distance between columns.
+    
+        - 0 - calculate distance between rows.
+        - 1 - calculate distance between columns.
+    
     kwargs : 
         Additional keyword arguments to be passed to 
-        scipy.cluster.hierarchy.distance.pdist
+        :func:`scipy.cluster.hierarchy.distance.pdist`
     
     Returns
     -------
@@ -152,8 +157,8 @@ def correlation(frame, method='pearson', axis=0):
     method : {pearson (default) | spearman | kendall}
         Type of correlations to be computed
     axis : {0, 1}
-        0 : Compute correlation between columns
-        1 : Compute correlation between rows
+        - 0 - Compute correlation between columns
+        - 1 - Compute correlation between rows
     
     Returns
     -------
@@ -322,8 +327,8 @@ def permute_w_replacement(frame, axis=0):
     frame : DataFrame
         Frame to permute.
     axis : {0, 1}
-        0 : Permute row values across columns
-        1 : Permute column values across rows    
+        - 0 - Permute row values across columns
+        - 1 - Permute column values across rows    
     
     Returns
     -------
