@@ -332,11 +332,11 @@ def zero_delta_cdf(params,x):
     cdf[x>0] = 1
     return cdf
 
-def test_dir_ll(ll_fun):
-    obs = np.array([[0.5,0.5],[0.9,0.1]])
-    a = [5.,5]
-    ll = ll_fun(a, obs)
-    return ll
+#def test_dir_ll(ll_fun):
+#    obs = np.array([[0.5,0.5],[0.9,0.1]])
+#    a = [5.,5]
+#    ll = ll_fun(a, obs)
+#    return ll
 
 if __name__ == '__main__':
     obs = np.array([[2.,8],[10,10000]])
