@@ -45,11 +45,7 @@ def filter_by_meta(frame, meta, criteria, axis='cols', verbose=True,
                    how='all', filter_missing=True):
     '''
     Filter frame by a metadata, keeping only cols/rows that pass the filtering criteria.
-    For more information see pysurvey.util.filters and pysurvey.filter_by_vals
-    Inputs:
-        criteria = [dict] keyed by metadata labels, with values being filtering functions returning bool.
-        axis     = [int/str] indicate whether to filter rows or cols.
-        filter_missing = [bool] indicate whether to filter out NAN's or not.
+    For more information see func:`pysurvey.util.filters` and func:`~pysurvey.filter_by_vals`
 
     Parameters
     ----------
