@@ -129,8 +129,6 @@ def clustered_heatmap(matrix, dist_mat=False, **kwargs):
     rstrip_kwargs = kwargs.pop('rstrip_kwargs', {})
     #general
     figsize   = kwargs.pop('figsize', (8,8))
-    file = kwargs.pop('file',None)
-    show = kwargs.pop('show',True)
     #interactive args
     interactive = kwargs.pop('interactive', True)
     interactive_kwargs = kwargs.pop('interactive_kwargs', {})
@@ -394,7 +392,6 @@ def clustered_heatmap(matrix, dist_mat=False, **kwargs):
             shrink_ax(cbar_ax, top=cwidthmax)
 
     fig.canvas.draw()
-    if file is not None: fig.savefig(file, bbox_inches='tight')
 
     if interactive:
         from interactive.annotators import HeatmapAnnotator
@@ -416,9 +413,6 @@ def clustered_heatmap(matrix, dist_mat=False, **kwargs):
                          axis=rstrip_ax,
                          xtol=1,
                          **rinteractive_kwargs)
-    
-    
-    if show: pl.show()
 
     return mat, rlabels_sorted, clabels_sorted, axes
 
@@ -440,59 +434,60 @@ def plot_heatmap(smat, **kwargs):
     kwargs['rstrip'] = rstrip
     return clustered_heatmap(matrix, **kwargs)
 
-def test_plot_heatmap():
-    from survey.metaFrame import MetaDataFrame
-    from survey import DataFrame
-    rows = ['r2', 'r0', 'r1']
-    cols = ['c0', 'c1']
-    metac = DataFrame([['sample1','big'],['sample0','small']], index = ['c1','c0'], columns = ['name', 'size'])
-    metar = DataFrame([['otu0',5],['otu2',10],['otu1',10]], index = ['r0','r2','r1'], columns = ['name', 'IQ'])
-    mat = np.array([ [2., 1], [1, 3], [10, 15] ])
-    df = MetaDataFrame(mat, index=rows, columns=cols, meta_cols = metac, meta_rows=metar)
-    plot_heatmap(df, 
-                 rstrip='IQ', cstrip='size',
-                 rsort=True, plot_rlabels=True, 
-                 csort=False, plot_clabels=True,
-                 cmap = 'hot', 
-                 rstrip_kwargs = {'cmap':'Accent'}, cstrip_kwargs = {'cmap':'Reds'},
-                 interactive_kwargs = {'text_kwargs' :{'color':'w','fontsize':15}},
-                 )
-
-def test_clustered_heatmap():
-    import scipy
-    n = 1000
-    m = 15
-    x = scipy.rand(n,m)
-    row_inds = [1,3,5,7]
-    col_inds = [0,2,4,6]
-    x[row_inds,:] *= 5
-    x[:,col_inds] *= 5
-    metric='euclidean'
-    
-#    cstrip = np.zeros(m)
-#    cstrip[col_inds] = 1
-    cstrip = array(['a']*m)
-    cstrip[1:4] = 'b'
-    cstrip[4:8] = 'c'
-    
-    rstrip = np.zeros(n)
-    rstrip[row_inds] = 1
-    
-    rlabels = map(lambda i: '' + str(i), range(n))
-    clabels = map(lambda i: 'abcefghij' +str(i), range(m))
-    clustered_heatmap(x, rlabels=rlabels, clabels=clabels, show=True,
-                cmap='jet', colorbar=True,
-                csort=False, rsort=True,
-                plot_clabels=True, plot_rlabels=True,
-#                rlabel_width=0.0,
-#                clabel_width=0.05,
-                cbfontsize=10,
-#                strip_width=0.05,
-                cstrip=cstrip, rstrip=rstrip)
+#def test_plot_heatmap():
+#    from survey.metaFrame import MetaDataFrame
+#    from survey import DataFrame
+#    rows = ['r2', 'r0', 'r1']
+#    cols = ['c0', 'c1']
+#    metac = DataFrame([['sample1','big'],['sample0','small']], index = ['c1','c0'], columns = ['name', 'size'])
+#    metar = DataFrame([['otu0',5],['otu2',10],['otu1',10]], index = ['r0','r2','r1'], columns = ['name', 'IQ'])
+#    mat = np.array([ [2., 1], [1, 3], [10, 15] ])
+#    df = MetaDataFrame(mat, index=rows, columns=cols, meta_cols = metac, meta_rows=metar)
+#    plot_heatmap(df, 
+#                 rstrip='IQ', cstrip='size',
+#                 rsort=True, plot_rlabels=True, 
+#                 csort=False, plot_clabels=True,
+#                 cmap = 'hot', 
+#                 rstrip_kwargs = {'cmap':'Accent'}, cstrip_kwargs = {'cmap':'Reds'},
+#                 interactive_kwargs = {'text_kwargs' :{'color':'w','fontsize':15}},
+#                 )
+#
+#def test_clustered_heatmap():
+#    import scipy
+#    n = 1000
+#    m = 15
+#    x = scipy.rand(n,m)
+#    row_inds = [1,3,5,7]
+#    col_inds = [0,2,4,6]
+#    x[row_inds,:] *= 5
+#    x[:,col_inds] *= 5
+#    metric='euclidean'
+#    
+##    cstrip = np.zeros(m)
+##    cstrip[col_inds] = 1
+#    cstrip = array(['a']*m)
+#    cstrip[1:4] = 'b'
+#    cstrip[4:8] = 'c'
+#    
+#    rstrip = np.zeros(n)
+#    rstrip[row_inds] = 1
+#    
+#    rlabels = map(lambda i: '' + str(i), range(n))
+#    clabels = map(lambda i: 'abcefghij' +str(i), range(m))
+#    clustered_heatmap(x, rlabels=rlabels, clabels=clabels, show=True,
+#                cmap='jet', colorbar=True,
+#                csort=False, rsort=True,
+#                plot_clabels=True, plot_rlabels=True,
+##                rlabel_width=0.0,
+##                clabel_width=0.05,
+#                cbfontsize=10,
+##                strip_width=0.05,
+#                cstrip=cstrip, rstrip=rstrip)
 
 
 if __name__ == '__main__':
-    test_clustered_heatmap()
+    pass
+#    test_clustered_heatmap()
 #    test_plot_heatmap()
                 
                 
