@@ -31,9 +31,7 @@ def plot_cols(frame, **kwargs):
     xticks       = kwargs.pop('xticks', np.arange(1, n + 1))
     labelx       = kwargs.pop('labelx', False) 
     xlabel_rot   = kwargs.pop('xlabel_rot', 90)
-    grid          = kwargs.pop('grid', True)
-    show          = kwargs.pop('show', True)
-    file          = kwargs.pop('file', False)    
+    grid          = kwargs.pop('grid', True)    
     ## plot
     if new_fig: plt.figure()   
     if logx: x    = np.log10(x)
@@ -56,14 +54,12 @@ def plot_cols(frame, **kwargs):
         plt.legend(**legend_kwargs)
     ## grid 
     plt.grid(grid)
-    ## save & show
-    if file is not None: plt.savefig(file, bbox_inches='tight')
-    if show: plt.show()
+
 
 def stacked_plot(frame, logx=False, logy=False, fs=16, legend=False, 
                  legend_kwargs={'loc':'best'}, xlabel=None, ylabel=None,
-                 labelx=False, xlabel_rot=90, grid=False, show=True, file=None, 
-                 interactive=True, annotator_kwargs={'write':True, 'draw':False,'title':True},
+                 labelx=False, xlabel_rot=90, grid=False, interactive=True, 
+                 annotator_kwargs={'write':True, 'draw':False,'title':True},
                  **kwargs):
     '''
     stacked (area) plot of all columns of frame.
@@ -107,16 +103,13 @@ def stacked_plot(frame, logx=False, logy=False, fs=16, legend=False,
         plt.legend(**legend_kwargs)
     ## grid 
     plt.grid(grid)
-    ## save & show
-    if file is not None: plt.savefig(file, bbox_inches='tight')
-    if show: 
-        if interactive:
-            from interactive.annotators import StackedAnnotator
-            xannotes    = np.asarray(xannotes, dtype = str)
-            col_annotes = np.asarray(col_annotes, dtype = str)
-            StackedAnnotator(x, data.T, xannotes=xannotes, yannotes=col_annotes, 
-                             **annotator_kwargs)
-        plt.show()   
+    if interactive:
+        from interactive.annotators import StackedAnnotator
+        xannotes    = np.asarray(xannotes, dtype = str)
+        col_annotes = np.asarray(col_annotes, dtype = str)
+        StackedAnnotator(x, data.T, xannotes=xannotes, yannotes=col_annotes, 
+                         **annotator_kwargs)
+ 
 
 def bar_plot(frame, style='stacked', **kwargs):
     '''
@@ -129,8 +122,6 @@ def bar_plot(frame, style='stacked', **kwargs):
     fs          = kwargs.pop('fs', 16)
     label_rows  = kwargs.pop('label_rows', True)
     rlabels  = kwargs.pop('rlabels',list(frame.index) )
-    show        = kwargs.pop('show', True)
-    file        = kwargs.pop('file', False)
     rotation    = kwargs.pop('rotation', 0)
     legend      = kwargs.pop('legend', False)
     clabels  = kwargs.pop('clabels', list(frame.columns))
@@ -157,16 +148,12 @@ def bar_plot(frame, style='stacked', **kwargs):
     if label_rows is True:    labels = rlabels
     elif label_rows is False: labels = []
     plt.xticks(x, labels, rotation=rotation)
-    ## show/save
-    if file is not None: plt.savefig(file, bbox_inches='tight')
-    if show:
-        if interactive:
-            from interactive.annotators import MultibarAnnotator
-            row_annotes = np.asarray(row_annotes, dtype = str)
-            col_annotes = np.asarray(col_annotes, dtype = str)
-            MultibarAnnotator(x, y, xannotes=row_annotes, yannotes=col_annotes,
-                              style = style, write=write, draw=draw, title=title)
-        plt.show()   
+    if interactive:
+        from interactive.annotators import MultibarAnnotator
+        row_annotes = np.asarray(row_annotes, dtype = str)
+        col_annotes = np.asarray(col_annotes, dtype = str)
+        MultibarAnnotator(x, y, xannotes=row_annotes, yannotes=col_annotes,
+                          style=style, write=write, draw=draw, title=title)  
     
 
 def plot_heatmap(frame, **kwargs):
@@ -230,8 +217,6 @@ def plot_range_abunance(frame, **kwargs):
     range_log = kwargs.get('range_log', False)
     frac_log  = kwargs.get('frac_log', True)
     fs        = kwargs.get('fs', 16)
-    show      = kwargs.get('show', False)
-    file      = kwargs.get('file', False)
     
     plt.figure()
     ## get average fraction of each otu
@@ -264,9 +249,7 @@ def plot_range_abunance(frame, **kwargs):
         str_x = .05
         str_y = .95
         ax    = plt.gca()
-        plt.text(str_x, str_y, s, bbox=dict(boxstyle="round", fc="0.8"), transform = ax.transAxes, ha = 'left',va = 'top')
-    if file is not None: plt.savefig(file)
-    if show: plt.show()            
+        plt.text(str_x, str_y, s, bbox=dict(boxstyle="round", fc="0.8"), transform = ax.transAxes, ha = 'left',va = 'top')         
 
 
 def plot_incidence_abunance(frame, **kwargs):
@@ -276,8 +259,6 @@ def plot_incidence_abunance(frame, **kwargs):
     range_log = kwargs.get('range_log', False)
     frac_log  = kwargs.get('frac_log', True)
     fs        = kwargs.get('fs', 16)
-    show      = kwargs.get('show', True)
-    file      = kwargs.get('file', False)
     
     n,k = np.shape(frame)
     n*=1.
@@ -310,8 +291,6 @@ def plot_incidence_abunance(frame, **kwargs):
         str_y = .95
         ax    = plt.gca()
         plt.text(str_x, str_y, s, bbox=dict(boxstyle="round", fc="0.8"), transform = ax.transAxes, ha = 'left',va = 'top')
-    if file is not None: plt.savefig(file)
-    if show: plt.show() 
 
 def GMM_plot(frame, n_components, metric=None, **kwargs):
     from pysurvey.analysis.GMM import plot_GMM
@@ -319,13 +298,11 @@ def GMM_plot(frame, n_components, metric=None, **kwargs):
     from pandas import Series
     fs   = kwargs.pop('fs', 16)
     grid = kwargs.pop('grid', True)
-    show = kwargs.pop('show', True)
-    file = kwargs.pop('file', False)
     kwargs.setdefault('sample_labels',list(frame.index))  
     points, eigs = PCoA(frame, metric)
     var = eigs/eigs.sum() *100
     X = points.values[:,:2]
-    gmm, splot = plot_GMM(X,n_components, show=False, **kwargs) 
+    gmm, splot = plot_GMM(X,n_components, **kwargs) 
     xl = ('PC1 (%.1f' %var[0]) + '%)'
     yl = ('PC2 (%.1f' %var[1]) + '%)'
     splot.set_xlabel(xl, fontsize=fs)
@@ -335,9 +312,6 @@ def GMM_plot(frame, n_components, metric=None, **kwargs):
     membership_hard.sort()
     ## grid 
     plt.grid(grid)
-    ## save & show
-    if file is not None: plt.savefig(file, bbox_inches='tight')
-    if show: plt.show()
     return membership_hard, gmm, points, eigs  
 
 def plot_rank_abundance(frame, **kwargs):
@@ -358,23 +332,23 @@ def plot_rank_abundance(frame, **kwargs):
     ranked.plot_cols(**kwargs)
     return ranked
 
-
-def test_plot_heatmap(df):
-    plot_heatmap(df,
-                 rmeta=metar, cmeta=metac, 
-                 rstrip='IQ', cstrip='size',
-                 rsort=True, plot_rlabels=True, 
-                 csort=False, plot_clabels=True,
-                 cmap = 'hot', 
-                 rstrip_kwargs = {'cmap':'Accent'}, cstrip_kwargs = {'cmap':'Reds'},
-                 interactive_kwargs = {'text_kwargs' :{'color':'w','fontsize':15}},
-                 )   
-     
-
-def test_stacked_plot(df):
-    stacked_plot(df, legend=True, 
-             xlabel='Sample', ylabel='Fraction', labelx=True)     
-     
+#
+#def test_plot_heatmap(df):
+#    plot_heatmap(df,
+#                 rmeta=metar, cmeta=metac, 
+#                 rstrip='IQ', cstrip='size',
+#                 rsort=True, plot_rlabels=True, 
+#                 csort=False, plot_clabels=True,
+#                 cmap = 'hot', 
+#                 rstrip_kwargs = {'cmap':'Accent'}, cstrip_kwargs = {'cmap':'Reds'},
+#                 interactive_kwargs = {'text_kwargs' :{'color':'w','fontsize':15}},
+#                 )   
+#     
+#
+#def test_stacked_plot(df):
+#    stacked_plot(df, legend=True, 
+#             xlabel='Sample', ylabel='Fraction', labelx=True)     
+#     
 if __name__ == '__main__':
     from pandas import DataFrame
     rows = ['r2', 'r0', 'r1']
@@ -384,6 +358,6 @@ if __name__ == '__main__':
     mat = np.array([ [2., 1], [1, 3], [10, 15] ])
     df = DataFrame(mat, index=rows, columns=cols)
 #    test_stacked_plot(df)
-    test_plot_heatmap(df)
+#    test_plot_heatmap(df)
     
     
