@@ -1057,43 +1057,43 @@ def kde_2d(m1,m2):
     plt.ylim(ymin,ymax)
     plt.axes().set_aspect('auto', 'box')
     return kernel
-    
-
-def test_confusion():
-    from HMPStructures.HMPmatrix import HMP_matrix
-    k = 3
-    node_ids = [str(i) for i in xrange(k)]
-    mat1      = np.eye(k)
-    mat1[0,1] = -1
-    mat1[1,0] = -1
-    m1 = HMP_matrix()
-    m1.from_matrix(mat1, node_ids, node_ids)
-    
-    mat2      = np.eye(k)
-    mat2[2,1] = 1
-    mat2[1,2] = 1
-    m2 = HMP_matrix()
-    m2.from_matrix(mat2, node_ids, node_ids)
-    
-    net1 = OTUnetwork(node_ids = node_ids, matrix = m1)
-    net2 = OTUnetwork(node_ids = node_ids, matrix = m2)
-    add_edges(net1, cutoff = 0.5, statistic = 'matrix', method = 'abs_larger')
-    add_edges(net2, cutoff = 0.5, statistic = 'matrix', method = 'abs_larger')
-    print confusion_mat(net1,net2)
-
-def test_add_edges():
-    from DataStructures.MyDataMatrix import MyDataMatrix as DM
-    vals = np.array([[0,1,0],
-                     [1,0,1],
-                     [0,1,0]])
-    ids = ['aa','bb','cc']
-    matrix = DM(vals, index=ids, columns=ids)
-    net = OTUnetwork(matrix)
-    add_edges(net, node='bb')
-    print net.edges()
-    
-    
-    
+#    
+#
+#def test_confusion():
+#    from HMPStructures.HMPmatrix import HMP_matrix
+#    k = 3
+#    node_ids = [str(i) for i in xrange(k)]
+#    mat1      = np.eye(k)
+#    mat1[0,1] = -1
+#    mat1[1,0] = -1
+#    m1 = HMP_matrix()
+#    m1.from_matrix(mat1, node_ids, node_ids)
+#    
+#    mat2      = np.eye(k)
+#    mat2[2,1] = 1
+#    mat2[1,2] = 1
+#    m2 = HMP_matrix()
+#    m2.from_matrix(mat2, node_ids, node_ids)
+#    
+#    net1 = OTUnetwork(node_ids = node_ids, matrix = m1)
+#    net2 = OTUnetwork(node_ids = node_ids, matrix = m2)
+#    add_edges(net1, cutoff = 0.5, statistic = 'matrix', method = 'abs_larger')
+#    add_edges(net2, cutoff = 0.5, statistic = 'matrix', method = 'abs_larger')
+#    print confusion_mat(net1,net2)
+#
+#def test_add_edges():
+#    from DataStructures.MyDataMatrix import MyDataMatrix as DM
+#    vals = np.array([[0,1,0],
+#                     [1,0,1],
+#                     [0,1,0]])
+#    ids = ['aa','bb','cc']
+#    matrix = DM(vals, index=ids, columns=ids)
+#    net = OTUnetwork(matrix)
+#    add_edges(net, node='bb')
+#    print net.edges()
+#    
+#    
+#    
 if __name__ == '__main__':
     from DataStructures.MyDataMatrix import MyDataMatrix as DM
     path = '/Users/jonathanfriedman/Documents/Alm/enterotype/correlations/'
