@@ -23,6 +23,8 @@ expectedActors = {'sum': np.sum,
                   'med': np.median,
                   'var': np.var,
                   'std': np.std,
+                  'min': np.min,
+                  'max': np.max,
                   'presence': filters._presence_fun,
                   }
 
