@@ -2,6 +2,9 @@
 Created on Dec 20, 2011
 
 @author: jonathanfriedman
+
+Parts of this file (path trickety) were adopted from the pandas
+project, which is distributed under a BSD license.
 '''
 import unittest, os, tempfile
 import numpy as np
@@ -21,25 +24,28 @@ lins_d = {'otu_1':'k__Bacteria;p__Nitrospirae;c__Nitrospira;o__Nitrospirales;f__
           'otu_2':'k__Bacteria;p__Bacteroidetes;c__Bacteroidia;o__Bacteroidales;f__Rikenellaceae;g__;s__',
           'otu_3': 'k__Bacteria;p__Bacteroidetes;c__Bacteroidia;o__Bacteroidales;f__Prevotellaceae;g__Prevotella;s__'}
 expected_lins = Lineages.from_dict(lins_d)
- 
+
+def curpath():
+    pth, _ = os.path.split(os.path.abspath(__file__))
+    return pth
 
 class TestLineages(unittest.TestCase):
     def setUp(self):
         pass
         
     def test_read_txt(self):
-        countsfile = 'data/fake_data.counts'
+        countsfile = os.path.join(curpath(), 'data/fake_data.counts') 
         counts = io.read_txt(countsfile, verbose=False) 
         assert_frame_equal(counts, expected_counts)
         countsT = io.read_txt(countsfile, T=False, verbose=False) 
         assert_frame_equal(countsT, expected_counts.T)
         
-        countsfile = 'data/fake_data_lin.counts'
+        countsfile = os.path.join(curpath(), 'data/fake_data_lin.counts') 
         counts,lins = io.read_txt(countsfile, verbose=False)
         assert_frame_equal(counts, expected_counts)
         self.assertEqual(lins, expected_lins)
         
-        countsfile = 'data/fake_data_lin2.counts'
+        countsfile = os.path.join(curpath(), 'data/fake_data_lin2.counts') 
         counts,lins = io.read_txt(countsfile, verbose=False,
                                   lin=True, lin_label='consensus lins')
         assert_frame_equal(counts, expected_counts)
