@@ -211,61 +211,61 @@ class Information():
         return PI_mat
 
 
-def test():
-    from TimeSeriesAnalysis import Generate_TS
-    import matplotlib.pyplot as plt
-    import warnings; warnings.filterwarnings('ignore')
-                    
-    n = 50
-    c_vec = np.linspace(0,.99,10)
-    
-    MI_expected = 0.5 *((1+c_vec)*np.log(1+c_vec) + (1-c_vec)*np.log(1-c_vec))
-    TE_expected = 0.5 * c_vec * ((1+c_vec)*np.log(1+c_vec) - (1-c_vec)*np.log(1-c_vec)) - 0.5 *(1+c_vec**2)*np.log(1+c_vec**2)
-    
-    alphabet1 = np.arange(2)
-    alphabet2 = np.arange(2)
-    alphabet  = [alphabet1, alphabet2]
-    method    = 'cmeans_ML'
-    shared_alph = True
-    MI = np.array([])
-    TExy = np.array([])
-    TEyx = np.array([])
-    PIxy = np.array([])
-    PIyx = np.array([])
-    k = 2
-    r = 2
-    for c in c_vec:
-        x1,x2 = Generate_TS.TE_test_series(n,c) 
-        x = [x1,x2]
-        prob = Information(x,alphabet, pmf_method = method, shared_alph = shared_alph)
-        MI   = np.append(MI, prob.MI(x, k=k, r=r)[0][0,1])
-        TE    = prob.transfer_entropy(x, k=k, r=r)
-        TExy  = np.append(TExy, TE[1,0])
-        TEyx  = np.append(TEyx, TE[0,1])
-        PI    = prob.pred_improve(x)
-        PIxy  = np.append(PIxy, PI[1,0])
-        PIyx  = np.append(PIyx, PI[0,1])
-
-        
-    fig = plt.figure()
-    ax  = fig.add_subplot(111)
-    h = ax.plot(c_vec,MI_expected,c_vec,MI)
-    legend_s = ['MI_theory','MI_sim']
-    fig.legend(h,legend_s)
-#    plt.show()
-    
-    fig = plt.figure()
-    ax  = fig.add_subplot(111)
-    h = ax.plot(c_vec,TE_expected,c_vec,TExy,c_vec,TEyx)
-    legend_s = ['TE_theory','TExy_sim', 'TEyx_sim']
-    fig.legend(h,legend_s)
-    
-    fig = plt.figure()
-    ax  = fig.add_subplot(111)
-    h = ax.plot(c_vec,PIxy,c_vec,PIyx)
-    legend_s = ['PIxy_sim', 'PIyx_sim']
-    fig.legend(h,legend_s)
-    plt.show()    
+#def test():
+#    from TimeSeriesAnalysis import Generate_TS
+#    import matplotlib.pyplot as plt
+#    import warnings; warnings.filterwarnings('ignore')
+#                    
+#    n = 50
+#    c_vec = np.linspace(0,.99,10)
+#    
+#    MI_expected = 0.5 *((1+c_vec)*np.log(1+c_vec) + (1-c_vec)*np.log(1-c_vec))
+#    TE_expected = 0.5 * c_vec * ((1+c_vec)*np.log(1+c_vec) - (1-c_vec)*np.log(1-c_vec)) - 0.5 *(1+c_vec**2)*np.log(1+c_vec**2)
+#    
+#    alphabet1 = np.arange(2)
+#    alphabet2 = np.arange(2)
+#    alphabet  = [alphabet1, alphabet2]
+#    method    = 'cmeans_ML'
+#    shared_alph = True
+#    MI = np.array([])
+#    TExy = np.array([])
+#    TEyx = np.array([])
+#    PIxy = np.array([])
+#    PIyx = np.array([])
+#    k = 2
+#    r = 2
+#    for c in c_vec:
+#        x1,x2 = Generate_TS.TE_test_series(n,c) 
+#        x = [x1,x2]
+#        prob = Information(x,alphabet, pmf_method = method, shared_alph = shared_alph)
+#        MI   = np.append(MI, prob.MI(x, k=k, r=r)[0][0,1])
+#        TE    = prob.transfer_entropy(x, k=k, r=r)
+#        TExy  = np.append(TExy, TE[1,0])
+#        TEyx  = np.append(TEyx, TE[0,1])
+#        PI    = prob.pred_improve(x)
+#        PIxy  = np.append(PIxy, PI[1,0])
+#        PIyx  = np.append(PIyx, PI[0,1])
+#
+#        
+#    fig = plt.figure()
+#    ax  = fig.add_subplot(111)
+#    h = ax.plot(c_vec,MI_expected,c_vec,MI)
+#    legend_s = ['MI_theory','MI_sim']
+#    fig.legend(h,legend_s)
+##    plt.show()
+#    
+#    fig = plt.figure()
+#    ax  = fig.add_subplot(111)
+#    h = ax.plot(c_vec,TE_expected,c_vec,TExy,c_vec,TEyx)
+#    legend_s = ['TE_theory','TExy_sim', 'TEyx_sim']
+#    fig.legend(h,legend_s)
+#    
+#    fig = plt.figure()
+#    ax  = fig.add_subplot(111)
+#    h = ax.plot(c_vec,PIxy,c_vec,PIyx)
+#    legend_s = ['PIxy_sim', 'PIyx_sim']
+#    fig.legend(h,legend_s)
+#    plt.show()    
     
 
 if __name__ == '__main__':   
