@@ -24,6 +24,8 @@ namedActors = {'sum': ('sum',),
                'med': ('median','med'),
                'var': ('var','variance'),
                'std': ('std','standard-deviation'),
+               'min': ('min','minimum'),
+               'max': ('max','maximum'),
                'presence': ('present','presence'),
              }
 
@@ -100,6 +102,10 @@ def parse_actor(actor):
             return np.var
         elif a in namedActors['std']:
             return np.std
+        elif a in namedActors['min']:
+            return np.min
+        elif a in namedActors['max']:
+            return np.max
         elif a in namedActors['presence']:
             return _presence_fun
         else:
@@ -226,7 +232,7 @@ def parse_filters(criteria, nan_val=None):
     else:
         try:
             filters   = (Filter(criteria, nan_val),) 
-        except ValueError:
+        except Exception:
             filters = tuple()
             for c in criteria:
                 if isinstance(c, Filter):
